@@ -3,7 +3,7 @@ from rest_framework import serializers
 
 from django.contrib.auth import get_user_model
 
-from edx_name_affirmation.models import VerifiedName
+from edx_name_affirmation.models import VerifiedName, VerifiedNameConfig
 
 User = get_user_model()
 
@@ -29,3 +29,19 @@ class VerifiedNameSerializer(serializers.ModelSerializer):
             "created", "username", "verified_name", "profile_name", "verification_attempt_id",
             "proctored_exam_attempt_id", "is_verified"
         )
+
+
+class VerifiedNameConfigSerializer(serializers.ModelSerializer):
+    """
+    Serializer for the VerifiedNameConfig Model.
+    """
+    username = serializers.CharField(source="user.username")
+    use_verified_name_for_certs = serializers.BooleanField(required=False, allow_null=True)
+
+    class Meta:
+        """
+        Meta Class
+        """
+        model = VerifiedNameConfig
+
+        fields = ("change_date", "username", "use_verified_name_for_certs")
